# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v0/sequencer_connect_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v0/sequencer_connect_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import service_agreement_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2
from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from ....protocol.v1 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_sequencing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEcom/digitalasset/canton/domain/api/v0/sequencer_connect_service.proto\x12%com.digitalasset.canton.domain.api.v0\x1a=com/digitalasset/canton/domain/api/v0/service_agreement.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x34\x63om/digitalasset/canton/protocol/v1/sequencing.proto\"\xcf\x05\n\x10SequencerConnect\x1a\x64\n\x0bGetDomainId\x1a\t\n\x07Request\x1aJ\n\x08Response\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12!\n\x0csequencer_id\x18\x02 \x01(\tR\x0bsequencerId\x1a\x83\x02\n\x13GetDomainParameters\x1a\t\n\x07Request\x1a\xe0\x01\n\x08Response\x12\x62\n\rparameters_v0\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v0.StaticDomainParametersH\x00R\x0cparametersV0\x12\x62\n\rparameters_v1\x18\x02 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v1.StaticDomainParametersH\x00R\x0cparametersV1B\x0c\n\nparameters\x1a\xce\x02\n\x0cVerifyActive\x1a\t\n\x07Request\x1a\xe7\x01\n\x08Response\x12h\n\x07success\x18\x01 \x01(\x0b\x32L.com.digitalasset.canton.domain.api.v0.SequencerConnect.VerifyActive.SuccessH\x00R\x07success\x12h\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32L.com.digitalasset.canton.domain.api.v0.SequencerConnect.VerifyActive.FailureH\x00R\x07\x66\x61ilureB\x07\n\x05value\x1a&\n\x07Success\x12\x1b\n\tis_active\x18\x01 \x01(\x08R\x08isActive\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason2\xd2\x06\n\x17SequencerConnectService\x12|\n\tHandshake\x12\x36.com.digitalasset.canton.protocol.v0.Handshake.Request\x1a\x37.com.digitalasset.canton.protocol.v0.Handshake.Response\x12\xa8\x01\n\x0bGetDomainId\x12K.com.digitalasset.canton.domain.api.v0.SequencerConnect.GetDomainId.Request\x1aL.com.digitalasset.canton.domain.api.v0.SequencerConnect.GetDomainId.Response\x12\xc0\x01\n\x13GetDomainParameters\x12S.com.digitalasset.canton.domain.api.v0.SequencerConnect.GetDomainParameters.Request\x1aT.com.digitalasset.canton.domain.api.v0.SequencerConnect.GetDomainParameters.Response\x12\xab\x01\n\x0cVerifyActive\x12L.com.digitalasset.canton.domain.api.v0.SequencerConnect.VerifyActive.Request\x1aM.com.digitalasset.canton.domain.api.v0.SequencerConnect.VerifyActive.Response\x12\x9c\x01\n\x13GetServiceAgreement\x12\x41.com.digitalasset.canton.domain.api.v0.GetServiceAgreementRequest\x1a\x42.com.digitalasset.canton.domain.api.v0.GetServiceAgreementResponseBVZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v0.sequencer_connect_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0'
  _globals['_SEQUENCERCONNECT']._serialized_start=284
  _globals['_SEQUENCERCONNECT']._serialized_end=1003
  _globals['_SEQUENCERCONNECT_GETDOMAINID']._serialized_start=304
  _globals['_SEQUENCERCONNECT_GETDOMAINID']._serialized_end=404
  _globals['_SEQUENCERCONNECT_GETDOMAINID_REQUEST']._serialized_start=319
  _globals['_SEQUENCERCONNECT_GETDOMAINID_REQUEST']._serialized_end=328
  _globals['_SEQUENCERCONNECT_GETDOMAINID_RESPONSE']._serialized_start=330
  _globals['_SEQUENCERCONNECT_GETDOMAINID_RESPONSE']._serialized_end=404
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERS']._serialized_start=407
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERS']._serialized_end=666
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERS_REQUEST']._serialized_start=319
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERS_REQUEST']._serialized_end=328
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERS_RESPONSE']._serialized_start=442
  _globals['_SEQUENCERCONNECT_GETDOMAINPARAMETERS_RESPONSE']._serialized_end=666
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE']._serialized_start=669
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE']._serialized_end=1003
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE_REQUEST']._serialized_start=319
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE_REQUEST']._serialized_end=328
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE_RESPONSE']._serialized_start=697
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE_RESPONSE']._serialized_end=928
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE_SUCCESS']._serialized_start=930
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE_SUCCESS']._serialized_end=968
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE_FAILURE']._serialized_start=970
  _globals['_SEQUENCERCONNECT_VERIFYACTIVE_FAILURE']._serialized_end=1003
  _globals['_SEQUENCERCONNECTSERVICE']._serialized_start=1006
  _globals['_SEQUENCERCONNECTSERVICE']._serialized_end=1856
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v1/participant_transaction.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v1/participant_transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ..v0 import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_common__pb2
from ..v0 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transaction__pb2
from ..v0 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_common__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_merkle__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAcom/digitalasset/canton/protocol/v1/participant_transaction.proto\x12#com.digitalasset.canton.protocol.v1\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x30\x63om/digitalasset/canton/protocol/v0/common.proto\x1a\x41\x63om/digitalasset/canton/protocol/v0/participant_transaction.proto\x1a\x32\x63om/digitalasset/canton/protocol/v0/topology.proto\x1a\x30\x63om/digitalasset/canton/protocol/v1/common.proto\x1a\x30\x63om/digitalasset/canton/protocol/v1/merkle.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc2\x08\n\x11\x41\x63tionDescription\x12h\n\x06\x63reate\x18\x01 \x01(\x0b\x32N.com.digitalasset.canton.protocol.v0.ActionDescription.CreateActionDescriptionH\x00R\x06\x63reate\x12n\n\x08\x65xercise\x18\x02 \x01(\x0b\x32P.com.digitalasset.canton.protocol.v1.ActionDescription.ExerciseActionDescriptionH\x00R\x08\x65xercise\x12\x65\n\x05\x66\x65tch\x18\x03 \x01(\x0b\x32M.com.digitalasset.canton.protocol.v0.ActionDescription.FetchActionDescriptionH\x00R\x05\x66\x65tch\x12y\n\rlookup_by_key\x18\x04 \x01(\x0b\x32S.com.digitalasset.canton.protocol.v0.ActionDescription.LookupByKeyActionDescriptionH\x00R\x0blookupByKey\x1a\xb9\x02\n\x19\x45xerciseActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x63hoice\x18\x02 \x01(\tR\x06\x63hoice\x12!\n\x0c\x63hosen_value\x18\x03 \x01(\x0cR\x0b\x63hosenValue\x12\x16\n\x06\x61\x63tors\x18\x04 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x05 \x01(\x08R\x05\x62yKey\x12\x1b\n\tnode_seed\x18\x06 \x01(\x0cR\x08nodeSeed\x12\x18\n\x07version\x18\x07 \x01(\tR\x07version\x12\x16\n\x06\x66\x61iled\x18\x08 \x01(\x08R\x06\x66\x61iled\x12&\n\x0cinterface_id\x18\t \x01(\tH\x00R\x0binterfaceId\x88\x01\x01\x42\x0f\n\r_interface_id\x1a`\n\x1cLookupByKeyActionDescription\x12@\n\x03key\x18\x01 \x01(\x0b\x32..com.digitalasset.canton.protocol.v1.GlobalKeyR\x03key\x1a\xc3\x01\n\x16\x46\x65tchActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x61\x63tors\x18\x02 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x03 \x01(\x08R\x05\x62yKey\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\x12$\n\x0btemplate_id\x18\x05 \x01(\tH\x00R\ntemplateId\x88\x01\x01\x42\x0e\n\x0c_template_idB\r\n\x0b\x64\x65scription\"\x9c\x02\n\x08ViewNode\x12\\\n\x10view_common_data\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v1.BlindableNodeR\x0eviewCommonData\x12\x66\n\x15view_participant_data\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v1.BlindableNodeR\x13viewParticipantData\x12J\n\x08subviews\x18\x03 \x01(\x0b\x32..com.digitalasset.canton.protocol.v1.MerkleSeqR\x08subviews\"\xb8\x01\n\x0eViewCommonData\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12K\n\tinformees\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.protocol.v1.InformeeR\tinformees\x12\x1c\n\tthreshold\x18\x03 \x01(\x05R\tthreshold\"\x9b\x01\n\x08Informee\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x16\n\x06weight\x18\x02 \x01(\x05R\x06weight\x12\x61\n\x14required_trust_level\x18\x03 \x01(\x0e\x32/.com.digitalasset.canton.protocol.v0.TrustLevelR\x12requiredTrustLevel\"\xf5\x03\n\x14\x45ncryptedViewMessage\x12\x1b\n\tview_tree\x18\x01 \x01(\x0cR\x08viewTree\x12\x62\n\x11\x65ncryption_scheme\x18\x02 \x01(\x0e\x32\x35.com.digitalasset.canton.crypto.v0.SymmetricKeySchemeR\x10\x65ncryptionScheme\x12t\n\x1fsubmitter_participant_signature\x18\x03 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\x1dsubmitterParticipantSignature\x12\x1b\n\tview_hash\x18\x04 \x01(\x0cR\x08viewHash\x12`\n\nrandomness\x18\x05 \x03(\x0b\x32@.com.digitalasset.canton.protocol.v1.ParticipantRandomnessLookupR\nrandomness\x12\x1b\n\tdomain_id\x18\x06 \x01(\tR\x08\x64omainId\x12J\n\tview_type\x18\x07 \x01(\x0e\x32-.com.digitalasset.canton.protocol.v0.ViewTypeR\x08viewType\"_\n\x1bParticipantRandomnessLookup\x12\x1e\n\nrandomness\x18\x01 \x01(\x0cR\nrandomness\x12 \n\x0b\x66ingerprint\x18\x02 \x01(\tR\x0b\x66ingerprint\"\x1c\n\x16ViewParticipantMessage:\x02\x18\x01\"\xa1\x01\n\x0fInformeeMessage\x12\x63\n\x12\x66ull_informee_tree\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v1.FullInformeeTreeR\x10\x66ullInformeeTree\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\"\x8e\x01\n\x18LightTransactionViewTree\x12K\n\x04tree\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v1.GenTransactionTreeR\x04tree\x12%\n\x0esubview_hashes\x18\x02 \x03(\x0cR\rsubviewHashes\"_\n\x10\x46ullInformeeTree\x12K\n\x04tree\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v1.GenTransactionTreeR\x04tree\"\xb3\x01\n\x0f\x43reatedContract\x12U\n\x08\x63ontract\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v1.SerializableContractR\x08\x63ontract\x12(\n\x10\x63onsumed_in_core\x18\x02 \x01(\x08R\x0e\x63onsumedInCore\x12\x1f\n\x0brolled_back\x18\x03 \x01(\x08R\nrolledBack\"\x82\x01\n\rInputContract\x12U\n\x08\x63ontract\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v1.SerializableContractR\x08\x63ontract\x12\x1a\n\x08\x63onsumed\x18\x02 \x01(\x08R\x08\x63onsumed\"\xb0\x03\n\x11SubmitterMetadata\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12\x15\n\x06\x61\x63t_as\x18\x02 \x03(\tR\x05\x61\x63tAs\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x04 \x01(\tR\tcommandId\x12\x33\n\x15submitter_participant\x18\x05 \x01(\tR\x14submitterParticipant\x12#\n\rsubmission_id\x18\x06 \x01(\tR\x0csubmissionId\x12[\n\x0c\x64\x65\x64up_period\x18\x07 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.DeduplicationPeriodR\x0b\x64\x65\x64upPeriod\x12J\n\x13max_sequencing_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11maxSequencingTime\"\xd8\x01\n\x0bResolvedKey\x12@\n\x03key\x18\x01 \x01(\x0b\x32..com.digitalasset.canton.protocol.v1.GlobalKeyR\x03key\x12!\n\x0b\x63ontract_id\x18\x02 \x01(\tH\x00R\ncontractId\x12V\n\x04\x66ree\x18\x03 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v0.ViewParticipantData.FreeKeyH\x00R\x04\x66reeB\x0c\n\nresolutionBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v1.participant_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1'
  _globals['_VIEWPARTICIPANTMESSAGE']._loaded_options = None
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_options = b'\030\001'
  _globals['_ACTIONDESCRIPTION']._serialized_start=457
  _globals['_ACTIONDESCRIPTION']._serialized_end=1547
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_start=923
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_end=1236
  _globals['_ACTIONDESCRIPTION_LOOKUPBYKEYACTIONDESCRIPTION']._serialized_start=1238
  _globals['_ACTIONDESCRIPTION_LOOKUPBYKEYACTIONDESCRIPTION']._serialized_end=1334
  _globals['_ACTIONDESCRIPTION_FETCHACTIONDESCRIPTION']._serialized_start=1337
  _globals['_ACTIONDESCRIPTION_FETCHACTIONDESCRIPTION']._serialized_end=1532
  _globals['_VIEWNODE']._serialized_start=1550
  _globals['_VIEWNODE']._serialized_end=1834
  _globals['_VIEWCOMMONDATA']._serialized_start=1837
  _globals['_VIEWCOMMONDATA']._serialized_end=2021
  _globals['_INFORMEE']._serialized_start=2024
  _globals['_INFORMEE']._serialized_end=2179
  _globals['_ENCRYPTEDVIEWMESSAGE']._serialized_start=2182
  _globals['_ENCRYPTEDVIEWMESSAGE']._serialized_end=2683
  _globals['_PARTICIPANTRANDOMNESSLOOKUP']._serialized_start=2685
  _globals['_PARTICIPANTRANDOMNESSLOOKUP']._serialized_end=2780
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_start=2782
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_end=2810
  _globals['_INFORMEEMESSAGE']._serialized_start=2813
  _globals['_INFORMEEMESSAGE']._serialized_end=2974
  _globals['_LIGHTTRANSACTIONVIEWTREE']._serialized_start=2977
  _globals['_LIGHTTRANSACTIONVIEWTREE']._serialized_end=3119
  _globals['_FULLINFORMEETREE']._serialized_start=3121
  _globals['_FULLINFORMEETREE']._serialized_end=3216
  _globals['_CREATEDCONTRACT']._serialized_start=3219
  _globals['_CREATEDCONTRACT']._serialized_end=3398
  _globals['_INPUTCONTRACT']._serialized_start=3401
  _globals['_INPUTCONTRACT']._serialized_end=3531
  _globals['_SUBMITTERMETADATA']._serialized_start=3534
  _globals['_SUBMITTERMETADATA']._serialized_end=3966
  _globals['_RESOLVEDKEY']._serialized_start=3969
  _globals['_RESOLVEDKEY']._serialized_end=4185
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencer_connection_pb2 import SequencerApiType, SequencerConnection
from .service_agreement_pb2 import GetServiceAgreementRequest, GetServiceAgreementResponse
from .domain_service_pb2_grpc import DomainServiceStub
from .domain_time_service_pb2 import AwaitTimeRequest, FetchTimeRequest, FetchTimeResponse
from .domain_time_service_pb2_grpc import DomainTimeServiceStub
from .sequencer_authentication_service_pb2 import Authentication, Challenge
from .sequencer_authentication_service_pb2_grpc import SequencerAuthenticationServiceStub
from .sequencer_connect_service_pb2 import SequencerConnect
from .sequencer_connect_service_pb2_grpc import SequencerConnectServiceStub
from .sequencer_service_pb2 import AcknowledgeRequest, SendAsyncResponse, SendAsyncSignedResponse, SendAsyncUnauthenticatedVersionedRequest, SendAsyncVersionedRequest, SequencedEventTrafficState, SubscriptionRequest, SubscriptionResponse, VersionedSubscriptionResponse
from .sequencer_service_pb2_grpc import SequencerServiceStub

__all__ = [
    "AcknowledgeRequest",
    "Authentication",
    "AwaitTimeRequest",
    "Challenge",
    "DomainServiceStub",
    "DomainTimeServiceStub",
    "FetchTimeRequest",
    "FetchTimeResponse",
    "GetServiceAgreementRequest",
    "GetServiceAgreementResponse",
    "SendAsyncResponse",
    "SendAsyncSignedResponse",
    "SendAsyncUnauthenticatedVersionedRequest",
    "SendAsyncVersionedRequest",
    "SequencedEventTrafficState",
    "SequencerApiType",
    "SequencerAuthenticationServiceStub",
    "SequencerConnect",
    "SequencerConnectServiceStub",
    "SequencerConnection",
    "SequencerServiceStub",
    "SubscriptionRequest",
    "SubscriptionResponse",
    "VersionedSubscriptionResponse",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .initialization_service_pb2 import GetIdResponse, InitIdRequest, InitIdResponse
from .initialization_service_pb2_grpc import InitializationServiceStub
from .topology_aggregation_service_pb2 import ListKeyOwnersRequest, ListKeyOwnersResponse, ListPartiesRequest, ListPartiesResponse
from .topology_aggregation_service_pb2_grpc import TopologyAggregationServiceStub
from .topology_manager_read_service_pb2 import BaseQuery, BaseResult, ListAllRequest, ListAllResponse, ListAvailableStoresRequest, ListAvailableStoresResult, ListDomainParametersChangesRequest, ListDomainParametersChangesResult, ListIdentifierDelegationRequest, ListIdentifierDelegationResult, ListMediatorDomainStateRequest, ListMediatorDomainStateResult, ListNamespaceDelegationRequest, ListNamespaceDelegationResult, ListOwnerToKeyMappingRequest, ListOwnerToKeyMappingResult, ListParticipantDomainStateRequest, ListParticipantDomainStateResult, ListPartyToParticipantRequest, ListPartyToParticipantResult, ListSignedLegalIdentityClaimRequest, ListSignedLegalIdentityClaimResult, ListVettedPackagesRequest, ListVettedPackagesResult
from .topology_manager_read_service_pb2_grpc import TopologyManagerReadServiceStub
from .topology_manager_write_service_pb2 import AdditionSuccess, AuthorizationData, AuthorizationSuccess, DomainParametersChangeAuthorization, IdentifierDelegationAuthorization, MediatorDomainStateAuthorization, NamespaceDelegationAuthorization, OwnerToKeyMappingAuthorization, ParticipantDomainStateAuthorization, PartyToParticipantAuthorization, SignedTopologyTransactionAddition, VettedPackagesAuthorization
from .topology_manager_write_service_pb2_grpc import TopologyManagerWriteServiceStub

__all__ = [
    "AdditionSuccess",
    "AuthorizationData",
    "AuthorizationSuccess",
    "BaseQuery",
    "BaseResult",
    "DomainParametersChangeAuthorization",
    "GetIdResponse",
    "IdentifierDelegationAuthorization",
    "InitIdRequest",
    "InitIdResponse",
    "InitializationServiceStub",
    "ListAllRequest",
    "ListAllResponse",
    "ListAvailableStoresRequest",
    "ListAvailableStoresResult",
    "ListDomainParametersChangesRequest",
    "ListDomainParametersChangesResult",
    "ListIdentifierDelegationRequest",
    "ListIdentifierDelegationResult",
    "ListKeyOwnersRequest",
    "ListKeyOwnersResponse",
    "ListMediatorDomainStateRequest",
    "ListMediatorDomainStateResult",
    "ListNamespaceDelegationRequest",
    "ListNamespaceDelegationResult",
    "ListOwnerToKeyMappingRequest",
    "ListOwnerToKeyMappingResult",
    "ListParticipantDomainStateRequest",
    "ListParticipantDomainStateResult",
    "ListPartiesRequest",
    "ListPartiesResponse",
    "ListPartyToParticipantRequest",
    "ListPartyToParticipantResult",
    "ListSignedLegalIdentityClaimRequest",
    "ListSignedLegalIdentityClaimResult",
    "ListVettedPackagesRequest",
    "ListVettedPackagesResult",
    "MediatorDomainStateAuthorization",
    "NamespaceDelegationAuthorization",
    "OwnerToKeyMappingAuthorization",
    "ParticipantDomainStateAuthorization",
    "PartyToParticipantAuthorization",
    "SignedTopologyTransactionAddition",
    "TopologyAggregationServiceStub",
    "TopologyManagerReadServiceStub",
    "TopologyManagerWriteServiceStub",
    "VettedPackagesAuthorization",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReceivedCommitmentState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    RECEIVED_COMMITMENT_STATE_UNSPECIFIED: _ClassVar[ReceivedCommitmentState]
    RECEIVED_COMMITMENT_STATE_MATCH: _ClassVar[ReceivedCommitmentState]
    RECEIVED_COMMITMENT_STATE_MISMATCH: _ClassVar[ReceivedCommitmentState]
    RECEIVED_COMMITMENT_STATE_BUFFERED: _ClassVar[ReceivedCommitmentState]
    RECEIVED_COMMITMENT_STATE_OUTSTANDING: _ClassVar[ReceivedCommitmentState]

class SentCommitmentState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SENT_COMMITMENT_STATE_UNSPECIFIED: _ClassVar[SentCommitmentState]
    SENT_COMMITMENT_STATE_MATCH: _ClassVar[SentCommitmentState]
    SENT_COMMITMENT_STATE_MISMATCH: _ClassVar[SentCommitmentState]
    SENT_COMMITMENT_STATE_NOT_COMPARED: _ClassVar[SentCommitmentState]
RECEIVED_COMMITMENT_STATE_UNSPECIFIED: ReceivedCommitmentState
RECEIVED_COMMITMENT_STATE_MATCH: ReceivedCommitmentState
RECEIVED_COMMITMENT_STATE_MISMATCH: ReceivedCommitmentState
RECEIVED_COMMITMENT_STATE_BUFFERED: ReceivedCommitmentState
RECEIVED_COMMITMENT_STATE_OUTSTANDING: ReceivedCommitmentState
SENT_COMMITMENT_STATE_UNSPECIFIED: SentCommitmentState
SENT_COMMITMENT_STATE_MATCH: SentCommitmentState
SENT_COMMITMENT_STATE_MISMATCH: SentCommitmentState
SENT_COMMITMENT_STATE_NOT_COMPARED: SentCommitmentState

class LookupContractDomain(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("contract_id",)
        CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        contract_id: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, contract_id: _Optional[_Iterable[str]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("results",)
        class ResultsEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        RESULTS_FIELD_NUMBER: _ClassVar[int]
        results: _containers.ScalarMap[str, str]
        def __init__(self, results: _Optional[_Mapping[str, str]] = ...) -> None: ...
    def __init__(self) -> None: ...

class LookupTransactionDomain(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("transaction_id",)
        TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
        transaction_id: str
        def __init__(self, transaction_id: _Optional[str] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("domain_id",)
        DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
        domain_id: str
        def __init__(self, domain_id: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class LookupOffsetByTime(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("timestamp",)
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        timestamp: _timestamp_pb2.Timestamp
        def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("offset",)
        OFFSET_FIELD_NUMBER: _ClassVar[int]
        offset: str
        def __init__(self, offset: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class LookupOffsetByIndex(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("index",)
        INDEX_FIELD_NUMBER: _ClassVar[int]
        index: int
        def __init__(self, index: _Optional[int] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("offset",)
        OFFSET_FIELD_NUMBER: _ClassVar[int]
        offset: str
        def __init__(self, offset: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class LookupReceivedAcsCommitments(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("time_ranges", "counter_participant_uids", "commitment_state", "verbose")
        TIME_RANGES_FIELD_NUMBER: _ClassVar[int]
        COUNTER_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
        COMMITMENT_STATE_FIELD_NUMBER: _ClassVar[int]
        VERBOSE_FIELD_NUMBER: _ClassVar[int]
        time_ranges: _containers.RepeatedCompositeFieldContainer[DomainTimeRange]
        counter_participant_uids: _containers.RepeatedScalarFieldContainer[str]
        commitment_state: _containers.RepeatedScalarFieldContainer[ReceivedCommitmentState]
        verbose: bool
        def __init__(self, time_ranges: _Optional[_Iterable[_Union[DomainTimeRange, _Mapping]]] = ..., counter_participant_uids: _Optional[_Iterable[str]] = ..., commitment_state: _Optional[_Iterable[_Union[ReceivedCommitmentState, str]]] = ..., verbose: bool = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("received",)
        RECEIVED_FIELD_NUMBER: _ClassVar[int]
        received: _containers.RepeatedCompositeFieldContainer[ReceivedAcsCommitmentPerDomain]
        def __init__(self, received: _Optional[_Iterable[_Union[ReceivedAcsCommitmentPerDomain, _Mapping]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class TimeRange(_message.Message):
    __slots__ = ("from_exclusive", "to_inclusive")
    FROM_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    from_exclusive: _timestamp_pb2.Timestamp
    to_inclusive: _timestamp_pb2.Timestamp
    def __init__(self, from_exclusive: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., to_inclusive: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DomainTimeRange(_message.Message):
    __slots__ = ("domain_id", "interval")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    interval: TimeRange
    def __init__(self, domain_id: _Optional[str] = ..., interval: _Optional[_Union[TimeRange, _Mapping]] = ...) -> None: ...

class Interval(_message.Message):
    __slots__ = ("start_tick_exclusive", "end_tick_inclusive")
    START_TICK_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    END_TICK_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    start_tick_exclusive: _timestamp_pb2.Timestamp
    end_tick_inclusive: _timestamp_pb2.Timestamp
    def __init__(self, start_tick_exclusive: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_tick_inclusive: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ReceivedAcsCommitment(_message.Message):
    __slots__ = ("interval", "origin_counter_participant_uid", "received_commitment", "own_commitment", "state")
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    RECEIVED_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    OWN_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    interval: Interval
    origin_counter_participant_uid: str
    received_commitment: bytes
    own_commitment: bytes
    state: ReceivedCommitmentState
    def __init__(self, interval: _Optional[_Union[Interval, _Mapping]] = ..., origin_counter_participant_uid: _Optional[str] = ..., received_commitment: _Optional[bytes] = ..., own_commitment: _Optional[bytes] = ..., state: _Optional[_Union[ReceivedCommitmentState, str]] = ...) -> None: ...

class ReceivedAcsCommitmentPerDomain(_message.Message):
    __slots__ = ("domain_id", "received")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    RECEIVED_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    received: _containers.RepeatedCompositeFieldContainer[ReceivedAcsCommitment]
    def __init__(self, domain_id: _Optional[str] = ..., received: _Optional[_Iterable[_Union[ReceivedAcsCommitment, _Mapping]]] = ...) -> None: ...

class SentAcsCommitment(_message.Message):
    __slots__ = ("interval", "dest_counter_participant_uid", "own_commitment", "received_commitment", "state")
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    DEST_COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    OWN_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    RECEIVED_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    interval: Interval
    dest_counter_participant_uid: str
    own_commitment: bytes
    received_commitment: bytes
    state: SentCommitmentState
    def __init__(self, interval: _Optional[_Union[Interval, _Mapping]] = ..., dest_counter_participant_uid: _Optional[str] = ..., own_commitment: _Optional[bytes] = ..., received_commitment: _Optional[bytes] = ..., state: _Optional[_Union[SentCommitmentState, str]] = ...) -> None: ...

class SentAcsCommitmentPerDomain(_message.Message):
    __slots__ = ("domain_id", "sent")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    SENT_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    sent: _containers.RepeatedCompositeFieldContainer[SentAcsCommitment]
    def __init__(self, domain_id: _Optional[str] = ..., sent: _Optional[_Iterable[_Union[SentAcsCommitment, _Mapping]]] = ...) -> None: ...

class LookupSentAcsCommitments(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("time_ranges", "counter_participant_uids", "commitment_state", "verbose")
        TIME_RANGES_FIELD_NUMBER: _ClassVar[int]
        COUNTER_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
        COMMITMENT_STATE_FIELD_NUMBER: _ClassVar[int]
        VERBOSE_FIELD_NUMBER: _ClassVar[int]
        time_ranges: _containers.RepeatedCompositeFieldContainer[DomainTimeRange]
        counter_participant_uids: _containers.RepeatedScalarFieldContainer[str]
        commitment_state: _containers.RepeatedScalarFieldContainer[SentCommitmentState]
        verbose: bool
        def __init__(self, time_ranges: _Optional[_Iterable[_Union[DomainTimeRange, _Mapping]]] = ..., counter_participant_uids: _Optional[_Iterable[str]] = ..., commitment_state: _Optional[_Iterable[_Union[SentCommitmentState, str]]] = ..., verbose: bool = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("sent",)
        SENT_FIELD_NUMBER: _ClassVar[int]
        sent: _containers.RepeatedCompositeFieldContainer[SentAcsCommitmentPerDomain]
        def __init__(self, sent: _Optional[_Iterable[_Union[SentAcsCommitmentPerDomain, _Mapping]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class SlowCounterParticipantDomainConfig(_message.Message):
    __slots__ = ("domain_ids", "distinguished_participant_uids", "threshold_distinguished", "threshold_default", "participant_uids_metrics")
    DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
    DISTINGUISHED_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_DISTINGUISHED_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_UIDS_METRICS_FIELD_NUMBER: _ClassVar[int]
    domain_ids: _containers.RepeatedScalarFieldContainer[str]
    distinguished_participant_uids: _containers.RepeatedScalarFieldContainer[str]
    threshold_distinguished: int
    threshold_default: int
    participant_uids_metrics: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, domain_ids: _Optional[_Iterable[str]] = ..., distinguished_participant_uids: _Optional[_Iterable[str]] = ..., threshold_distinguished: _Optional[int] = ..., threshold_default: _Optional[int] = ..., participant_uids_metrics: _Optional[_Iterable[str]] = ...) -> None: ...

class SetConfigForSlowCounterParticipants(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("configs",)
        CONFIGS_FIELD_NUMBER: _ClassVar[int]
        configs: _containers.RepeatedCompositeFieldContainer[SlowCounterParticipantDomainConfig]
        def __init__(self, configs: _Optional[_Iterable[_Union[SlowCounterParticipantDomainConfig, _Mapping]]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class GetConfigForSlowCounterParticipants(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("domain_ids",)
        DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
        domain_ids: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, domain_ids: _Optional[_Iterable[str]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("configs",)
        CONFIGS_FIELD_NUMBER: _ClassVar[int]
        configs: _containers.RepeatedCompositeFieldContainer[SlowCounterParticipantDomainConfig]
        def __init__(self, configs: _Optional[_Iterable[_Union[SlowCounterParticipantDomainConfig, _Mapping]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class GetIntervalsBehindForCounterParticipants(_message.Message):
    __slots__ = ()
    class CounterParticipantInfo(_message.Message):
        __slots__ = ("counter_participant_uid", "domain_id", "intervals_behind", "as_of_sequencing_timestamp")
        COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
        DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
        INTERVALS_BEHIND_FIELD_NUMBER: _ClassVar[int]
        AS_OF_SEQUENCING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        counter_participant_uid: str
        domain_id: str
        intervals_behind: int
        as_of_sequencing_timestamp: _timestamp_pb2.Timestamp
        def __init__(self, counter_participant_uid: _Optional[str] = ..., domain_id: _Optional[str] = ..., intervals_behind: _Optional[int] = ..., as_of_sequencing_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    class Request(_message.Message):
        __slots__ = ("counter_participant_uids", "domain_ids", "threshold")
        COUNTER_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
        DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
        THRESHOLD_FIELD_NUMBER: _ClassVar[int]
        counter_participant_uids: _containers.RepeatedScalarFieldContainer[str]
        domain_ids: _containers.RepeatedScalarFieldContainer[str]
        threshold: int
        def __init__(self, counter_participant_uids: _Optional[_Iterable[str]] = ..., domain_ids: _Optional[_Iterable[str]] = ..., threshold: _Optional[int] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("intervals_behind",)
        INTERVALS_BEHIND_FIELD_NUMBER: _ClassVar[int]
        intervals_behind: _containers.RepeatedCompositeFieldContainer[GetIntervalsBehindForCounterParticipants.CounterParticipantInfo]
        def __init__(self, intervals_behind: _Optional[_Iterable[_Union[GetIntervalsBehindForCounterParticipants.CounterParticipantInfo, _Mapping]]] = ...) -> None: ...
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/sequencer_initialization_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/admin/v0/sequencer_initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from . import sequencer_initialization_snapshot_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_sequencer__initialization__snapshot__pb2
from ..v1 import sequencer_initialization_service_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v1_dot_sequencer__initialization__service__pb2
from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from ....protocol.v0 import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__ext__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/domain/admin/v0/sequencer_initialization_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1aOcom/digitalasset/canton/domain/admin/v0/sequencer_initialization_snapshot.proto\x1aNcom/digitalasset/canton/domain/admin/v1/sequencer_initialization_service.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x36\x63om/digitalasset/canton/protocol/v0/topology_ext.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xd4\x02\n\x0bInitRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12\x66\n\x11topology_snapshot\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.TopologyTransactionsR\x10topologySnapshot\x12h\n\x11\x64omain_parameters\x18\x04 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v0.StaticDomainParametersR\x10\x64omainParameters\x12V\n\x08snapshot\x18\x03 \x01(\x0b\x32:.com.digitalasset.canton.domain.admin.v0.SequencerSnapshotR\x08snapshot\"\x99\x01\n\x0cInitResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12R\n\npublic_key\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\tpublicKey\x12\x1e\n\nreplicated\x18\x03 \x01(\x08R\nreplicated\"\x91\x01\n\x18TopologyBootstrapRequest\x12u\n\x19initial_topology_snapshot\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.TopologyTransactionsR\x17initialTopologySnapshot2\x8c\x02\n\x1eSequencerInitializationService\x12s\n\x04Init\x12\x34.com.digitalasset.canton.domain.admin.v0.InitRequest\x1a\x35.com.digitalasset.canton.domain.admin.v0.InitResponse\x12u\n\x06InitV1\x12\x34.com.digitalasset.canton.domain.admin.v1.InitRequest\x1a\x35.com.digitalasset.canton.domain.admin.v0.InitResponse2\x82\x01\n\x18TopologyBootstrapService\x12\x66\n\tBootstrap\x12\x41.com.digitalasset.canton.domain.admin.v0.TopologyBootstrapRequest\x1a\x16.google.protobuf.EmptyBwZugithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0/sequencerinitializationserviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.sequencer_initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Zugithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0/sequencerinitializationservice'
  _globals['_INITREQUEST']._serialized_start=472
  _globals['_INITREQUEST']._serialized_end=812
  _globals['_INITRESPONSE']._serialized_start=815
  _globals['_INITRESPONSE']._serialized_end=968
  _globals['_TOPOLOGYBOOTSTRAPREQUEST']._serialized_start=971
  _globals['_TOPOLOGYBOOTSTRAPREQUEST']._serialized_end=1116
  _globals['_SEQUENCERINITIALIZATIONSERVICE']._serialized_start=1119
  _globals['_SEQUENCERINITIALIZATIONSERVICE']._serialized_end=1387
  _globals['_TOPOLOGYBOOTSTRAPSERVICE']._serialized_start=1390
  _globals['_TOPOLOGYBOOTSTRAPSERVICE']._serialized_end=1520
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/participant_repair_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/participant_repair_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import domain_connectivity_pb2 as com_dot_digitalasset_dot_canton_dot_participant_dot_admin_dot_v0_dot_domain__connectivity__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/participant/admin/v0/participant_repair_service.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a\x46\x63om/digitalasset/canton/participant/admin/v0/domain_connectivity.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xa5\x04\n\x0f\x44ownloadRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12(\n\x10\x66ilter_domain_id\x18\x02 \x01(\tR\x0e\x66ilterDomainId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12)\n\x10protocol_version\x18\x04 \x01(\tR\x0fprotocolVersion\x12:\n\tchunkSize\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\tchunkSize\x12\x1f\n\x0bgzip_format\x18\x06 \x01(\x08R\ngzipFormat\x12\x90\x01\n\x17\x63ontract_domain_renames\x18\x07 \x03(\x0b\x32X.com.digitalasset.canton.participant.admin.v0.DownloadRequest.ContractDomainRenamesEntryR\x15\x63ontractDomainRenames\x12/\n\x13parties_offboarding\x18\x08 \x01(\x08R\x12partiesOffboarding\x1aH\n\x1a\x43ontractDomainRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xb5\x01\n\x15PurgeContractsRequest\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12!\n\x0c\x63ontract_ids\x18\x02 \x03(\tR\x0b\x63ontractIds\x12\x32\n\x15ignore_already_purged\x18\x03 \x01(\x08R\x13ignoreAlreadyPurged\x12-\n\x12offboarded_parties\x18\x04 \x03(\tR\x11offboardedParties\"\x18\n\x16PurgeContractsResponse\"(\n\x10\x41\x63sSnapshotChunk\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"S\n\rUploadRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12\x1f\n\x0bgzip_format\x18\x02 \x01(\x08R\ngzipFormat\"\x10\n\x0eUploadResponse\"\xf9\x01\n\x14MigrateDomainRequest\x12!\n\x0csource_alias\x18\x01 \x01(\tR\x0bsourceAlias\x12\x8b\x01\n\x1ftarget_domain_connection_config\x18\x02 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.admin.v0.DomainConnectionConfigR\x1ctargetDomainConnectionConfig\x12\x30\n\x05\x66orce\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x05\x66orce\"\x17\n\x15MigrateDomainResponse\"t\n\x0e\x41\x63tiveContract\x12)\n\x10protocol_version\x18\x01 \x01(\x05R\x0fprotocolVersion\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12\x1a\n\x08\x63ontract\x18\x03 \x01(\x0cR\x08\x63ontract\"\xc5\x04\n\x10\x45xportAcsRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12(\n\x10\x66ilter_domain_id\x18\x02 \x01(\tR\x0e\x66ilterDomainId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x91\x01\n\x17\x63ontract_domain_renames\x18\x04 \x03(\x0b\x32Y.com.digitalasset.canton.participant.admin.v0.ExportAcsRequest.ContractDomainRenamesEntryR\x15\x63ontractDomainRenames\x12/\n\x13parties_offboarding\x18\x05 \x01(\x08R\x12partiesOffboarding\x1aV\n\x0cTargetDomain\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\x1a\x95\x01\n\x1a\x43ontractDomainRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x61\n\x05value\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.participant.admin.v0.ExportAcsRequest.TargetDomainR\x05value:\x02\x38\x01\")\n\x11\x45xportAcsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\x90\x01\n\x10ImportAcsRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12+\n\x11onboarded_parties\x18\x03 \x03(\tR\x10onboardedParties\"\x13\n\x11ImportAcsResponse\"B\n\x1dPurgeDeactivatedDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\" \n\x1ePurgeDeactivatedDomainResponse\"\x92\x01\n\x13IgnoreEventsRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14IgnoreEventsResponse\"\x94\x01\n\x15UnignoreEventsRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x18\n\x16UnignoreEventsResponse2\xf7\n\n\x18ParticipantRepairService\x12\x8b\x01\n\x08\x44ownload\x12=.com.digitalasset.canton.participant.admin.v0.DownloadRequest\x1a>.com.digitalasset.canton.participant.admin.v0.AcsSnapshotChunk0\x01\x12\x8e\x01\n\tExportAcs\x12>.com.digitalasset.canton.participant.admin.v0.ExportAcsRequest\x1a?.com.digitalasset.canton.participant.admin.v0.ExportAcsResponse0\x01\x12\x85\x01\n\x06Upload\x12;.com.digitalasset.canton.participant.admin.v0.UploadRequest\x1a<.com.digitalasset.canton.participant.admin.v0.UploadResponse(\x01\x12\x8e\x01\n\tImportAcs\x12>.com.digitalasset.canton.participant.admin.v0.ImportAcsRequest\x1a?.com.digitalasset.canton.participant.admin.v0.ImportAcsResponse(\x01\x12\x9b\x01\n\x0ePurgeContracts\x12\x43.com.digitalasset.canton.participant.admin.v0.PurgeContractsRequest\x1a\x44.com.digitalasset.canton.participant.admin.v0.PurgeContractsResponse\x12\x98\x01\n\rMigrateDomain\x12\x42.com.digitalasset.canton.participant.admin.v0.MigrateDomainRequest\x1a\x43.com.digitalasset.canton.participant.admin.v0.MigrateDomainResponse\x12\xb3\x01\n\x16PurgeDeactivatedDomain\x12K.com.digitalasset.canton.participant.admin.v0.PurgeDeactivatedDomainRequest\x1aL.com.digitalasset.canton.participant.admin.v0.PurgeDeactivatedDomainResponse\x12\x95\x01\n\x0cIgnoreEvents\x12\x41.com.digitalasset.canton.participant.admin.v0.IgnoreEventsRequest\x1a\x42.com.digitalasset.canton.participant.admin.v0.IgnoreEventsResponse\x12\x9b\x01\n\x0eUnignoreEvents\x12\x43.com.digitalasset.canton.participant.admin.v0.UnignoreEventsRequest\x1a\x44.com.digitalasset.canton.participant.admin.v0.UnignoreEventsResponseB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.participant_repair_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_DOWNLOADREQUEST_CONTRACTDOMAINRENAMESENTRY']._loaded_options = None
  _globals['_DOWNLOADREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._loaded_options = None
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_DOWNLOADREQUEST']._serialized_start=265
  _globals['_DOWNLOADREQUEST']._serialized_end=814
  _globals['_DOWNLOADREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_start=742
  _globals['_DOWNLOADREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_end=814
  _globals['_PURGECONTRACTSREQUEST']._serialized_start=817
  _globals['_PURGECONTRACTSREQUEST']._serialized_end=998
  _globals['_PURGECONTRACTSRESPONSE']._serialized_start=1000
  _globals['_PURGECONTRACTSRESPONSE']._serialized_end=1024
  _globals['_ACSSNAPSHOTCHUNK']._serialized_start=1026
  _globals['_ACSSNAPSHOTCHUNK']._serialized_end=1066
  _globals['_UPLOADREQUEST']._serialized_start=1068
  _globals['_UPLOADREQUEST']._serialized_end=1151
  _globals['_UPLOADRESPONSE']._serialized_start=1153
  _globals['_UPLOADRESPONSE']._serialized_end=1169
  _globals['_MIGRATEDOMAINREQUEST']._serialized_start=1172
  _globals['_MIGRATEDOMAINREQUEST']._serialized_end=1421
  _globals['_MIGRATEDOMAINRESPONSE']._serialized_start=1423
  _globals['_MIGRATEDOMAINRESPONSE']._serialized_end=1446
  _globals['_ACTIVECONTRACT']._serialized_start=1448
  _globals['_ACTIVECONTRACT']._serialized_end=1564
  _globals['_EXPORTACSREQUEST']._serialized_start=1567
  _globals['_EXPORTACSREQUEST']._serialized_end=2148
  _globals['_EXPORTACSREQUEST_TARGETDOMAIN']._serialized_start=1910
  _globals['_EXPORTACSREQUEST_TARGETDOMAIN']._serialized_end=1996
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_start=1999
  _globals['_EXPORTACSREQUEST_CONTRACTDOMAINRENAMESENTRY']._serialized_end=2148
  _globals['_EXPORTACSRESPONSE']._serialized_start=2150
  _globals['_EXPORTACSRESPONSE']._serialized_end=2191
  _globals['_IMPORTACSREQUEST']._serialized_start=2194
  _globals['_IMPORTACSREQUEST']._serialized_end=2338
  _globals['_IMPORTACSRESPONSE']._serialized_start=2340
  _globals['_IMPORTACSRESPONSE']._serialized_end=2359
  _globals['_PURGEDEACTIVATEDDOMAINREQUEST']._serialized_start=2361
  _globals['_PURGEDEACTIVATEDDOMAINREQUEST']._serialized_end=2427
  _globals['_PURGEDEACTIVATEDDOMAINRESPONSE']._serialized_start=2429
  _globals['_PURGEDEACTIVATEDDOMAINRESPONSE']._serialized_end=2461
  _globals['_IGNOREEVENTSREQUEST']._serialized_start=2464
  _globals['_IGNOREEVENTSREQUEST']._serialized_end=2610
  _globals['_IGNOREEVENTSRESPONSE']._serialized_start=2612
  _globals['_IGNOREEVENTSRESPONSE']._serialized_end=2634
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_start=2637
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_end=2785
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_start=2787
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_end=2811
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_start=2814
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_end=4213
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrderingRequest(_message.Message):
    __slots__ = ("sequencer_uid", "content")
    SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    sequencer_uid: str
    content: _wrappers_pb2.BytesValue
    def __init__(self, sequencer_uid: _Optional[str] = ..., content: _Optional[_Union[_wrappers_pb2.BytesValue, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/initialization_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/topology/admin/v30/initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__ext__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/digitalasset/canton/topology/admin/v30/initialization_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a=com/digitalasset/canton/topology/admin/v30/topology_ext.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\rInitIdRequest\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\"\x10\n\x0eInitIdResponse\"^\n\rGetIdResponse\x12 \n\x0binitialized\x18\x01 \x01(\x08R\x0binitialized\x12+\n\x11unique_identifier\x18\x02 \x01(\tR\x10uniqueIdentifier\"\"\n GetOnboardingTransactionsRequest\"\x89\x01\n!GetOnboardingTransactionsResponse\x12\x64\n\x0ctransactions\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x0ctransactions\"\x0e\n\x0cGetIdRequest\"\x14\n\x12\x43urrentTimeRequest\"T\n\x13\x43urrentTimeResponse\x12=\n\x0c\x63urrent_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63urrentTime2\xea\x04\n\x1dIdentityInitializationService\x12\x7f\n\x06InitId\x12\x39.com.digitalasset.canton.topology.admin.v30.InitIdRequest\x1a:.com.digitalasset.canton.topology.admin.v30.InitIdResponse\x12\xb8\x01\n\x19GetOnboardingTransactions\x12L.com.digitalasset.canton.topology.admin.v30.GetOnboardingTransactionsRequest\x1aM.com.digitalasset.canton.topology.admin.v30.GetOnboardingTransactionsResponse\x12|\n\x05GetId\x12\x38.com.digitalasset.canton.topology.admin.v30.GetIdRequest\x1a\x39.com.digitalasset.canton.topology.admin.v30.GetIdResponse\x12\x8e\x01\n\x0b\x43urrentTime\x12>.com.digitalasset.canton.topology.admin.v30.CurrentTimeRequest\x1a?.com.digitalasset.canton.topology.admin.v30.CurrentTimeResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_INITIDREQUEST']._serialized_start=215
  _globals['_INITIDREQUEST']._serialized_end=275
  _globals['_INITIDRESPONSE']._serialized_start=277
  _globals['_INITIDRESPONSE']._serialized_end=293
  _globals['_GETIDRESPONSE']._serialized_start=295
  _globals['_GETIDRESPONSE']._serialized_end=389
  _globals['_GETONBOARDINGTRANSACTIONSREQUEST']._serialized_start=391
  _globals['_GETONBOARDINGTRANSACTIONSREQUEST']._serialized_end=425
  _globals['_GETONBOARDINGTRANSACTIONSRESPONSE']._serialized_start=428
  _globals['_GETONBOARDINGTRANSACTIONSRESPONSE']._serialized_end=565
  _globals['_GETIDREQUEST']._serialized_start=567
  _globals['_GETIDREQUEST']._serialized_end=581
  _globals['_CURRENTTIMEREQUEST']._serialized_start=583
  _globals['_CURRENTTIMEREQUEST']._serialized_end=603
  _globals['_CURRENTTIMERESPONSE']._serialized_start=605
  _globals['_CURRENTTIMERESPONSE']._serialized_end=689
  _globals['_IDENTITYINITIALIZATIONSERVICE']._serialized_start=692
  _globals['_IDENTITYINITIALIZATIONSERVICE']._serialized_end=1310
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HashAlgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    HASH_ALGORITHM_UNSPECIFIED: _ClassVar[HashAlgorithm]
    HASH_ALGORITHM_SHA256: _ClassVar[HashAlgorithm]

class HmacAlgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    HMAC_ALGORITHM_UNSPECIFIED: _ClassVar[HmacAlgorithm]
    HMAC_ALGORITHM_HMAC_SHA256: _ClassVar[HmacAlgorithm]

class SignatureFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SIGNATURE_FORMAT_UNSPECIFIED: _ClassVar[SignatureFormat]
    SIGNATURE_FORMAT_RAW: _ClassVar[SignatureFormat]

class EncryptionKeySpec(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ENCRYPTION_KEY_SPEC_UNSPECIFIED: _ClassVar[EncryptionKeySpec]
    ENCRYPTION_KEY_SPEC_EC_P256: _ClassVar[EncryptionKeySpec]
    ENCRYPTION_KEY_SPEC_RSA_2048: _ClassVar[EncryptionKeySpec]

class KeyPurpose(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    KEY_PURPOSE_UNSPECIFIED: _ClassVar[KeyPurpose]
    KEY_PURPOSE_SIGNING: _ClassVar[KeyPurpose]
    KEY_PURPOSE_ENCRYPTION: _ClassVar[KeyPurpose]

class SigningKeyScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SIGNING_KEY_SCHEME_UNSPECIFIED: _ClassVar[SigningKeyScheme]
    SIGNING_KEY_SCHEME_ED25519: _ClassVar[SigningKeyScheme]
    SIGNING_KEY_SCHEME_EC_DSA_P256: _ClassVar[SigningKeyScheme]
    SIGNING_KEY_SCHEME_EC_DSA_P384: _ClassVar[SigningKeyScheme]

class EncryptionAlgorithmSpec(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ENCRYPTION_ALGORITHM_SPEC_UNSPECIFIED: _ClassVar[EncryptionAlgorithmSpec]
    ENCRYPTION_ALGORITHM_SPEC_ECIES_HKDF_HMAC_SHA256_AES128GCM: _ClassVar[EncryptionAlgorithmSpec]
    ENCRYPTION_ALGORITHM_SPEC_ECIES_HKDF_HMAC_SHA256_AES128CBC: _ClassVar[EncryptionAlgorithmSpec]
    ENCRYPTION_ALGORITHM_SPEC_RSA_OAEP_SHA256: _ClassVar[EncryptionAlgorithmSpec]

class EncryptionKeyScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ENCRYPTION_KEY_SCHEME_UNSPECIFIED: _ClassVar[EncryptionKeyScheme]
    ENCRYPTION_KEY_SCHEME_ECIES_P256_HKDF_HMAC_SHA256_AES128GCM: _ClassVar[EncryptionKeyScheme]
    ENCRYPTION_KEY_SCHEME_ECIES_P256_HMAC_SHA256A_ES128CBC: _ClassVar[EncryptionKeyScheme]
    ENCRYPTION_KEY_SCHEME_RSA2048_OAEP_SHA256: _ClassVar[EncryptionKeyScheme]

class SymmetricKeyScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SYMMETRIC_KEY_SCHEME_UNSPECIFIED: _ClassVar[SymmetricKeyScheme]
    SYMMETRIC_KEY_SCHEME_AES128GCM: _ClassVar[SymmetricKeyScheme]

class CryptoKeyFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CRYPTO_KEY_FORMAT_UNSPECIFIED: _ClassVar[CryptoKeyFormat]
    CRYPTO_KEY_FORMAT_DER: _ClassVar[CryptoKeyFormat]
    CRYPTO_KEY_FORMAT_RAW: _ClassVar[CryptoKeyFormat]
    CRYPTO_KEY_FORMAT_SYMBOLIC: _ClassVar[CryptoKeyFormat]

class PbkdfScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PBKDF_SCHEME_UNSPECIFIED: _ClassVar[PbkdfScheme]
    PBKDF_SCHEME_ARGON2ID_MODE1: _ClassVar[PbkdfScheme]
HASH_ALGORITHM_UNSPECIFIED: HashAlgorithm
HASH_ALGORITHM_SHA256: HashAlgorithm
HMAC_ALGORITHM_UNSPECIFIED: HmacAlgorithm
HMAC_ALGORITHM_HMAC_SHA256: HmacAlgorithm
SIGNATURE_FORMAT_UNSPECIFIED: SignatureFormat
SIGNATURE_FORMAT_RAW: SignatureFormat
ENCRYPTION_KEY_SPEC_UNSPECIFIED: EncryptionKeySpec
ENCRYPTION_KEY_SPEC_EC_P256: EncryptionKeySpec
ENCRYPTION_KEY_SPEC_RSA_2048: EncryptionKeySpec
KEY_PURPOSE_UNSPECIFIED: KeyPurpose
KEY_PURPOSE_SIGNING: KeyPurpose
KEY_PURPOSE_ENCRYPTION: KeyPurpose
SIGNING_KEY_SCHEME_UNSPECIFIED: SigningKeyScheme
SIGNING_KEY_SCHEME_ED25519: SigningKeyScheme
SIGNING_KEY_SCHEME_EC_DSA_P256: SigningKeyScheme
SIGNING_KEY_SCHEME_EC_DSA_P384: SigningKeyScheme
ENCRYPTION_ALGORITHM_SPEC_UNSPECIFIED: EncryptionAlgorithmSpec
ENCRYPTION_ALGORITHM_SPEC_ECIES_HKDF_HMAC_SHA256_AES128GCM: EncryptionAlgorithmSpec
ENCRYPTION_ALGORITHM_SPEC_ECIES_HKDF_HMAC_SHA256_AES128CBC: EncryptionAlgorithmSpec
ENCRYPTION_ALGORITHM_SPEC_RSA_OAEP_SHA256: EncryptionAlgorithmSpec
ENCRYPTION_KEY_SCHEME_UNSPECIFIED: EncryptionKeyScheme
ENCRYPTION_KEY_SCHEME_ECIES_P256_HKDF_HMAC_SHA256_AES128GCM: EncryptionKeyScheme
ENCRYPTION_KEY_SCHEME_ECIES_P256_HMAC_SHA256A_ES128CBC: EncryptionKeyScheme
ENCRYPTION_KEY_SCHEME_RSA2048_OAEP_SHA256: EncryptionKeyScheme
SYMMETRIC_KEY_SCHEME_UNSPECIFIED: SymmetricKeyScheme
SYMMETRIC_KEY_SCHEME_AES128GCM: SymmetricKeyScheme
CRYPTO_KEY_FORMAT_UNSPECIFIED: CryptoKeyFormat
CRYPTO_KEY_FORMAT_DER: CryptoKeyFormat
CRYPTO_KEY_FORMAT_RAW: CryptoKeyFormat
CRYPTO_KEY_FORMAT_SYMBOLIC: CryptoKeyFormat
PBKDF_SCHEME_UNSPECIFIED: PbkdfScheme
PBKDF_SCHEME_ARGON2ID_MODE1: PbkdfScheme

class Hmac(_message.Message):
    __slots__ = ("algorithm", "hmac")
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    HMAC_FIELD_NUMBER: _ClassVar[int]
    algorithm: HmacAlgorithm
    hmac: bytes
    def __init__(self, algorithm: _Optional[_Union[HmacAlgorithm, str]] = ..., hmac: _Optional[bytes] = ...) -> None: ...

class Salt(_message.Message):
    __slots__ = ("hmac", "salt")
    HMAC_FIELD_NUMBER: _ClassVar[int]
    SALT_FIELD_NUMBER: _ClassVar[int]
    hmac: HmacAlgorithm
    salt: bytes
    def __init__(self, hmac: _Optional[_Union[HmacAlgorithm, str]] = ..., salt: _Optional[bytes] = ...) -> None: ...

class Signature(_message.Message):
    __slots__ = ("format", "signature", "signed_by")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FIELD_NUMBER: _ClassVar[int]
    format: SignatureFormat
    signature: bytes
    signed_by: str
    def __init__(self, format: _Optional[_Union[SignatureFormat, str]] = ..., signature: _Optional[bytes] = ..., signed_by: _Optional[str] = ...) -> None: ...

class PublicKey(_message.Message):
    __slots__ = ("signing_public_key", "encryption_public_key")
    SIGNING_PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    signing_public_key: SigningPublicKey
    encryption_public_key: EncryptionPublicKey
    def __init__(self, signing_public_key: _Optional[_Union[SigningPublicKey, _Mapping]] = ..., encryption_public_key: _Optional[_Union[EncryptionPublicKey, _Mapping]] = ...) -> None: ...

class PublicKeyWithName(_message.Message):
    __slots__ = ("public_key", "name")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    public_key: PublicKey
    name: str
    def __init__(self, public_key: _Optional[_Union[PublicKey, _Mapping]] = ..., name: _Optional[str] = ...) -> None: ...

class PrivateKey(_message.Message):
    __slots__ = ("signing_private_key", "encryption_private_key")
    SIGNING_PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    signing_private_key: SigningPrivateKey
    encryption_private_key: EncryptionPrivateKey
    def __init__(self, signing_private_key: _Optional[_Union[SigningPrivateKey, _Mapping]] = ..., encryption_private_key: _Optional[_Union[EncryptionPrivateKey, _Mapping]] = ...) -> None: ...

class SigningPublicKey(_message.Message):
    __slots__ = ("format", "public_key", "scheme")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    format: CryptoKeyFormat
    public_key: bytes
    scheme: SigningKeyScheme
    def __init__(self, format: _Optional[_Union[CryptoKeyFormat, str]] = ..., public_key: _Optional[bytes] = ..., scheme: _Optional[_Union[SigningKeyScheme, str]] = ...) -> None: ...

class SigningPrivateKey(_message.Message):
    __slots__ = ("id", "format", "private_key", "scheme")
    ID_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    id: str
    format: CryptoKeyFormat
    private_key: bytes
    scheme: SigningKeyScheme
    def __init__(self, id: _Optional[str] = ..., format: _Optional[_Union[CryptoKeyFormat, str]] = ..., private_key: _Optional[bytes] = ..., scheme: _Optional[_Union[SigningKeyScheme, str]] = ...) -> None: ...

class SigningKeyPair(_message.Message):
    __slots__ = ("public_key", "private_key")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: SigningPublicKey
    private_key: SigningPrivateKey
    def __init__(self, public_key: _Optional[_Union[SigningPublicKey, _Mapping]] = ..., private_key: _Optional[_Union[SigningPrivateKey, _Mapping]] = ...) -> None: ...

class EncryptionPublicKey(_message.Message):
    __slots__ = ("format", "public_key", "scheme", "key_spec")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    KEY_SPEC_FIELD_NUMBER: _ClassVar[int]
    format: CryptoKeyFormat
    public_key: bytes
    scheme: EncryptionKeyScheme
    key_spec: EncryptionKeySpec
    def __init__(self, format: _Optional[_Union[CryptoKeyFormat, str]] = ..., public_key: _Optional[bytes] = ..., scheme: _Optional[_Union[EncryptionKeyScheme, str]] = ..., key_spec: _Optional[_Union[EncryptionKeySpec, str]] = ...) -> None: ...

class EncryptionPrivateKey(_message.Message):
    __slots__ = ("id", "format", "private_key", "scheme", "key_spec")
    ID_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    KEY_SPEC_FIELD_NUMBER: _ClassVar[int]
    id: str
    format: CryptoKeyFormat
    private_key: bytes
    scheme: EncryptionKeyScheme
    key_spec: EncryptionKeySpec
    def __init__(self, id: _Optional[str] = ..., format: _Optional[_Union[CryptoKeyFormat, str]] = ..., private_key: _Optional[bytes] = ..., scheme: _Optional[_Union[EncryptionKeyScheme, str]] = ..., key_spec: _Optional[_Union[EncryptionKeySpec, str]] = ...) -> None: ...

class EncryptionKeyPair(_message.Message):
    __slots__ = ("public_key", "private_key")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: EncryptionPublicKey
    private_key: EncryptionPrivateKey
    def __init__(self, public_key: _Optional[_Union[EncryptionPublicKey, _Mapping]] = ..., private_key: _Optional[_Union[EncryptionPrivateKey, _Mapping]] = ...) -> None: ...

class RequiredEncryptionSpecs(_message.Message):
    __slots__ = ("algorithms", "keys")
    ALGORITHMS_FIELD_NUMBER: _ClassVar[int]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    algorithms: _containers.RepeatedScalarFieldContainer[EncryptionAlgorithmSpec]
    keys: _containers.RepeatedScalarFieldContainer[EncryptionKeySpec]
    def __init__(self, algorithms: _Optional[_Iterable[_Union[EncryptionAlgorithmSpec, str]]] = ..., keys: _Optional[_Iterable[_Union[EncryptionKeySpec, str]]] = ...) -> None: ...

class CryptoKeyPair(_message.Message):
    __slots__ = ("signing_key_pair", "encryption_key_pair")
    SIGNING_KEY_PAIR_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_KEY_PAIR_FIELD_NUMBER: _ClassVar[int]
    signing_key_pair: SigningKeyPair
    encryption_key_pair: EncryptionKeyPair
    def __init__(self, signing_key_pair: _Optional[_Union[SigningKeyPair, _Mapping]] = ..., encryption_key_pair: _Optional[_Union[EncryptionKeyPair, _Mapping]] = ...) -> None: ...

class SymmetricKey(_message.Message):
    __slots__ = ("format", "key", "scheme")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    format: CryptoKeyFormat
    key: bytes
    scheme: SymmetricKeyScheme
    def __init__(self, format: _Optional[_Union[CryptoKeyFormat, str]] = ..., key: _Optional[bytes] = ..., scheme: _Optional[_Union[SymmetricKeyScheme, str]] = ...) -> None: ...

class PasswordBasedEncrypted(_message.Message):
    __slots__ = ("ciphertext", "symmetric_key_scheme", "pbkdf_scheme", "salt")
    CIPHERTEXT_FIELD_NUMBER: _ClassVar[int]
    SYMMETRIC_KEY_SCHEME_FIELD_NUMBER: _ClassVar[int]
    PBKDF_SCHEME_FIELD_NUMBER: _ClassVar[int]
    SALT_FIELD_NUMBER: _ClassVar[int]
    ciphertext: bytes
    symmetric_key_scheme: SymmetricKeyScheme
    pbkdf_scheme: PbkdfScheme
    salt: bytes
    def __init__(self, ciphertext: _Optional[bytes] = ..., symmetric_key_scheme: _Optional[_Union[SymmetricKeyScheme, str]] = ..., pbkdf_scheme: _Optional[_Union[PbkdfScheme, str]] = ..., salt: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v30 import domain_parameters_pb2 as _domain_parameters_pb2
from ....protocol.v30 import topology_pb2 as _topology_pb2
from . import topology_ext_pb2 as _topology_ext_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BaseQuery(_message.Message):
    __slots__ = ("filter_store", "proposals", "operation", "snapshot", "head_state", "range", "filter_signed_key", "protocol_version")
    class TimeRange(_message.Message):
        __slots__ = ("until",)
        FROM_FIELD_NUMBER: _ClassVar[int]
        UNTIL_FIELD_NUMBER: _ClassVar[int]
        until: _timestamp_pb2.Timestamp
        def __init__(self, until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., **kwargs) -> None: ...
    FILTER_STORE_FIELD_NUMBER: _ClassVar[int]
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    HEAD_STATE_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    FILTER_SIGNED_KEY_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    filter_store: Store
    proposals: bool
    operation: _topology_pb2.Enums.TopologyChangeOp
    snapshot: _timestamp_pb2.Timestamp
    head_state: _empty_pb2.Empty
    range: BaseQuery.TimeRange
    filter_signed_key: str
    protocol_version: _wrappers_pb2.Int32Value
    def __init__(self, filter_store: _Optional[_Union[Store, _Mapping]] = ..., proposals: bool = ..., operation: _Optional[_Union[_topology_pb2.Enums.TopologyChangeOp, str]] = ..., snapshot: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., head_state: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., range: _Optional[_Union[BaseQuery.TimeRange, _Mapping]] = ..., filter_signed_key: _Optional[str] = ..., protocol_version: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...) -> None: ...

class Store(_message.Message):
    __slots__ = ("authorized", "domain")
    class Authorized(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Domain(_message.Message):
        __slots__ = ("id",)
        ID_FIELD_NUMBER: _ClassVar[int]
        id: str
        def __init__(self, id: _Optional[str] = ...) -> None: ...
    AUTHORIZED_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    authorized: Store.Authorized
    domain: Store.Domain
    def __init__(self, authorized: _Optional[_Union[Store.Authorized, _Mapping]] = ..., domain: _Optional[_Union[Store.Domain, _Mapping]] = ...) -> None: ...

class BaseResult(_message.Message):
    __slots__ = ("store", "sequenced", "valid_from", "valid_until", "operation", "transaction_hash", "serial", "signed_by_fingerprints")
    STORE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCED_FIELD_NUMBER: _ClassVar[int]
    VALID_FROM_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FINGERPRINTS_FIELD_NUMBER: _ClassVar[int]
    store: Store
    sequenced: _timestamp_pb2.Timestamp
    valid_from: _timestamp_pb2.Timestamp
    valid_until: _timestamp_pb2.Timestamp
    operation: _topology_pb2.Enums.TopologyChangeOp
    transaction_hash: bytes
    serial: int
    signed_by_fingerprints: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, store: _Optional[_Union[Store, _Mapping]] = ..., sequenced: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., valid_from: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., valid_until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., operation: _Optional[_Union[_topology_pb2.Enums.TopologyChangeOp, str]] = ..., transaction_hash: _Optional[bytes] = ..., serial: _Optional[int] = ..., signed_by_fingerprints: _Optional[_Iterable[str]] = ...) -> None: ...

class ListNamespaceDelegationRequest(_message.Message):
    __slots__ = ("base_query", "filter_namespace", "filter_target_key_fingerprint")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    FILTER_TARGET_KEY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_namespace: str
    filter_target_key_fingerprint: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_namespace: _Optional[str] = ..., filter_target_key_fingerprint: _Optional[str] = ...) -> None: ...

class ListNamespaceDelegationResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.NamespaceDelegation
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.NamespaceDelegation, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListNamespaceDelegationResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListNamespaceDelegationResponse.Result, _Mapping]]] = ...) -> None: ...

class ListDecentralizedNamespaceDefinitionRequest(_message.Message):
    __slots__ = ("base_query", "filter_namespace")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_namespace: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_namespace: _Optional[str] = ...) -> None: ...

class ListDecentralizedNamespaceDefinitionResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.DecentralizedNamespaceDefinition
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.DecentralizedNamespaceDefinition, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListDecentralizedNamespaceDefinitionResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListDecentralizedNamespaceDefinitionResponse.Result, _Mapping]]] = ...) -> None: ...

class ListIdentifierDelegationRequest(_message.Message):
    __slots__ = ("base_query", "filter_uid", "filter_target_key_fingerprint")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_UID_FIELD_NUMBER: _ClassVar[int]
    FILTER_TARGET_KEY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_uid: str
    filter_target_key_fingerprint: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_uid: _Optional[str] = ..., filter_target_key_fingerprint: _Optional[str] = ...) -> None: ...

class ListIdentifierDelegationResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.IdentifierDelegation
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.IdentifierDelegation, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListIdentifierDelegationResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListIdentifierDelegationResponse.Result, _Mapping]]] = ...) -> None: ...

class ListOwnerToKeyMappingRequest(_message.Message):
    __slots__ = ("base_query", "filter_key_owner_type", "filter_key_owner_uid")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_KEY_OWNER_TYPE_FIELD_NUMBER: _ClassVar[int]
    FILTER_KEY_OWNER_UID_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_key_owner_type: str
    filter_key_owner_uid: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_key_owner_type: _Optional[str] = ..., filter_key_owner_uid: _Optional[str] = ...) -> None: ...

class ListOwnerToKeyMappingResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.OwnerToKeyMapping
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.OwnerToKeyMapping, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListOwnerToKeyMappingResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListOwnerToKeyMappingResponse.Result, _Mapping]]] = ...) -> None: ...

class ListPartyToKeyMappingRequest(_message.Message):
    __slots__ = ("base_query", "filter_party")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTY_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_party: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_party: _Optional[str] = ...) -> None: ...

class ListPartyToKeyMappingResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.PartyToKeyMapping
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.PartyToKeyMapping, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListPartyToKeyMappingResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListPartyToKeyMappingResponse.Result, _Mapping]]] = ...) -> None: ...

class ListDomainTrustCertificateRequest(_message.Message):
    __slots__ = ("base_query", "filter_uid")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_UID_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_uid: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_uid: _Optional[str] = ...) -> None: ...

class ListDomainTrustCertificateResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.DomainTrustCertificate
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.DomainTrustCertificate, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListDomainTrustCertificateResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListDomainTrustCertificateResponse.Result, _Mapping]]] = ...) -> None: ...

class ListParticipantDomainPermissionRequest(_message.Message):
    __slots__ = ("base_query", "filter_uid")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_UID_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_uid: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_uid: _Optional[str] = ...) -> None: ...

class ListParticipantDomainPermissionResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.ParticipantDomainPermission
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.ParticipantDomainPermission, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListParticipantDomainPermissionResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListParticipantDomainPermissionResponse.Result, _Mapping]]] = ...) -> None: ...

class ListPartyHostingLimitsRequest(_message.Message):
    __slots__ = ("base_query", "filter_uid")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_UID_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_uid: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_uid: _Optional[str] = ...) -> None: ...

class ListPartyHostingLimitsResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.PartyHostingLimits
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.PartyHostingLimits, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListPartyHostingLimitsResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListPartyHostingLimitsResponse.Result, _Mapping]]] = ...) -> None: ...

class ListVettedPackagesRequest(_message.Message):
    __slots__ = ("base_query", "filter_participant")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_participant: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_participant: _Optional[str] = ...) -> None: ...

class ListVettedPackagesResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.VettedPackages
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.VettedPackages, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListVettedPackagesResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListVettedPackagesResponse.Result, _Mapping]]] = ...) -> None: ...

class ListPartyToParticipantRequest(_message.Message):
    __slots__ = ("base_query", "filter_party", "filter_participant")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_party: str
    filter_participant: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_party: _Optional[str] = ..., filter_participant: _Optional[str] = ...) -> None: ...

class ListPartyToParticipantResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.PartyToParticipant
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.PartyToParticipant, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListPartyToParticipantResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListPartyToParticipantResponse.Result, _Mapping]]] = ...) -> None: ...

class ListAuthorityOfRequest(_message.Message):
    __slots__ = ("base_query", "filter_party")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTY_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_party: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_party: _Optional[str] = ...) -> None: ...

class ListAuthorityOfResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.AuthorityOf
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.AuthorityOf, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListAuthorityOfResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListAuthorityOfResponse.Result, _Mapping]]] = ...) -> None: ...

class ListDomainParametersStateRequest(_message.Message):
    __slots__ = ("base_query", "filter_domain")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_domain: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_domain: _Optional[str] = ...) -> None: ...

class ListDomainParametersStateResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _domain_parameters_pb2.DynamicDomainParameters
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_domain_parameters_pb2.DynamicDomainParameters, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListDomainParametersStateResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListDomainParametersStateResponse.Result, _Mapping]]] = ...) -> None: ...

class ListMediatorDomainStateRequest(_message.Message):
    __slots__ = ("base_query", "filter_domain")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_domain: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_domain: _Optional[str] = ...) -> None: ...

class ListMediatorDomainStateResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.MediatorDomainState
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.MediatorDomainState, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListMediatorDomainStateResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListMediatorDomainStateResponse.Result, _Mapping]]] = ...) -> None: ...

class ListSequencerDomainStateRequest(_message.Message):
    __slots__ = ("base_query", "filter_domain")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_domain: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_domain: _Optional[str] = ...) -> None: ...

class ListSequencerDomainStateResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.SequencerDomainState
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.SequencerDomainState, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListSequencerDomainStateResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListSequencerDomainStateResponse.Result, _Mapping]]] = ...) -> None: ...

class ListPurgeTopologyTransactionRequest(_message.Message):
    __slots__ = ("base_query", "filter_domain")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_domain: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_domain: _Optional[str] = ...) -> None: ...

class ListPurgeTopologyTransactionResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.PurgeTopologyTransaction
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.PurgeTopologyTransaction, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListPurgeTopologyTransactionResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListPurgeTopologyTransactionResponse.Result, _Mapping]]] = ...) -> None: ...

class ListAvailableStoresRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListAvailableStoresResponse(_message.Message):
    __slots__ = ("store_ids",)
    STORE_IDS_FIELD_NUMBER: _ClassVar[int]
    store_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, store_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ListAllRequest(_message.Message):
    __slots__ = ("base_query", "exclude_mappings", "filter_namespace")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    EXCLUDE_MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    FILTER_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    exclude_mappings: _containers.RepeatedScalarFieldContainer[str]
    filter_namespace: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., exclude_mappings: _Optional[_Iterable[str]] = ..., filter_namespace: _Optional[str] = ...) -> None: ...

class ExportTopologySnapshotRequest(_message.Message):
    __slots__ = ("base_query", "exclude_mappings", "filter_namespace")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    EXCLUDE_MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    FILTER_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    exclude_mappings: _containers.RepeatedScalarFieldContainer[str]
    filter_namespace: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., exclude_mappings: _Optional[_Iterable[str]] = ..., filter_namespace: _Optional[str] = ...) -> None: ...

class ListAllResponse(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: _topology_ext_pb2.TopologyTransactions
    def __init__(self, result: _Optional[_Union[_topology_ext_pb2.TopologyTransactions, _Mapping]] = ...) -> None: ...

class ExportTopologySnapshotResponse(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: bytes
    def __init__(self, result: _Optional[bytes] = ...) -> None: ...

class GenesisStateRequest(_message.Message):
    __slots__ = ("filter_domain_store", "timestamp")
    FILTER_DOMAIN_STORE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    filter_domain_store: Store
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, filter_domain_store: _Optional[_Union[Store, _Mapping]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GenesisStateResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v30 import crypto_pb2 as _crypto_pb2
from . import participant_transaction_pb2 as _participant_transaction_pb2
from . import participant_transfer_pb2 as _participant_transfer_pb2
from . import topology_pb2 as _topology_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TypedSignedProtocolMessageContent(_message.Message):
    __slots__ = ("confirmation_response", "confirmation_result", "acs_commitment", "set_traffic_purchased")
    CONFIRMATION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    CONFIRMATION_RESULT_FIELD_NUMBER: _ClassVar[int]
    ACS_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    SET_TRAFFIC_PURCHASED_FIELD_NUMBER: _ClassVar[int]
    confirmation_response: bytes
    confirmation_result: bytes
    acs_commitment: bytes
    set_traffic_purchased: bytes
    def __init__(self, confirmation_response: _Optional[bytes] = ..., confirmation_result: _Optional[bytes] = ..., acs_commitment: _Optional[bytes] = ..., set_traffic_purchased: _Optional[bytes] = ...) -> None: ...

class SignedProtocolMessage(_message.Message):
    __slots__ = ("signature", "typed_signed_protocol_message_content")
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    TYPED_SIGNED_PROTOCOL_MESSAGE_CONTENT_FIELD_NUMBER: _ClassVar[int]
    signature: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    typed_signed_protocol_message_content: bytes
    def __init__(self, signature: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ..., typed_signed_protocol_message_content: _Optional[bytes] = ...) -> None: ...

class EnvelopeContent(_message.Message):
    __slots__ = ("informee_message", "encrypted_view_message", "transfer_out_mediator_message", "transfer_in_mediator_message", "root_hash_message", "topology_transactions_broadcast")
    INFORMEE_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_VIEW_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_OUT_MEDIATOR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_IN_MEDIATOR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_TRANSACTIONS_BROADCAST_FIELD_NUMBER: _ClassVar[int]
    informee_message: _participant_transaction_pb2.InformeeMessage
    encrypted_view_message: _participant_transaction_pb2.EncryptedViewMessage
    transfer_out_mediator_message: _participant_transfer_pb2.TransferOutMediatorMessage
    transfer_in_mediator_message: _participant_transfer_pb2.TransferInMediatorMessage
    root_hash_message: _participant_transaction_pb2.RootHashMessage
    topology_transactions_broadcast: _topology_pb2.TopologyTransactionsBroadcast
    def __init__(self, informee_message: _Optional[_Union[_participant_transaction_pb2.InformeeMessage, _Mapping]] = ..., encrypted_view_message: _Optional[_Union[_participant_transaction_pb2.EncryptedViewMessage, _Mapping]] = ..., transfer_out_mediator_message: _Optional[_Union[_participant_transfer_pb2.TransferOutMediatorMessage, _Mapping]] = ..., transfer_in_mediator_message: _Optional[_Union[_participant_transfer_pb2.TransferInMediatorMessage, _Mapping]] = ..., root_hash_message: _Optional[_Union[_participant_transaction_pb2.RootHashMessage, _Mapping]] = ..., topology_transactions_broadcast: _Optional[_Union[_topology_pb2.TopologyTransactionsBroadcast, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v0 import sequencing_pb2 as _sequencing_pb2
from . import common_pb2 as _common_pb2
from . import merkle_pb2 as _merkle_pb2
from ...time.v0 import time_proof_pb2 as _time_proof_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransferOutCommonData(_message.Message):
    __slots__ = ("salt", "source_domain", "stakeholders", "admin_parties", "uuid", "source_mediator", "source_protocol_version")
    SALT_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    ADMIN_PARTIES_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_MEDIATOR_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    source_domain: str
    stakeholders: _containers.RepeatedScalarFieldContainer[str]
    admin_parties: _containers.RepeatedScalarFieldContainer[str]
    uuid: str
    source_mediator: str
    source_protocol_version: int
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., source_domain: _Optional[str] = ..., stakeholders: _Optional[_Iterable[str]] = ..., admin_parties: _Optional[_Iterable[str]] = ..., uuid: _Optional[str] = ..., source_mediator: _Optional[str] = ..., source_protocol_version: _Optional[int] = ...) -> None: ...

class TransferViewTree(_message.Message):
    __slots__ = ("common_data", "participant_data")
    COMMON_DATA_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_DATA_FIELD_NUMBER: _ClassVar[int]
    common_data: _merkle_pb2.BlindableNode
    participant_data: _merkle_pb2.BlindableNode
    def __init__(self, common_data: _Optional[_Union[_merkle_pb2.BlindableNode, _Mapping]] = ..., participant_data: _Optional[_Union[_merkle_pb2.BlindableNode, _Mapping]] = ...) -> None: ...

class TransferInMediatorMessage(_message.Message):
    __slots__ = ("tree",)
    TREE_FIELD_NUMBER: _ClassVar[int]
    tree: TransferViewTree
    def __init__(self, tree: _Optional[_Union[TransferViewTree, _Mapping]] = ...) -> None: ...

class TransferOutMediatorMessage(_message.Message):
    __slots__ = ("tree",)
    TREE_FIELD_NUMBER: _ClassVar[int]
    tree: TransferViewTree
    def __init__(self, tree: _Optional[_Union[TransferViewTree, _Mapping]] = ...) -> None: ...

class TransferOutView(_message.Message):
    __slots__ = ("salt", "submitter", "contract_id", "target_domain", "target_time_proof", "target_protocol_version")
    SALT_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TARGET_TIME_PROOF_FIELD_NUMBER: _ClassVar[int]
    TARGET_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    submitter: str
    contract_id: str
    target_domain: str
    target_time_proof: _time_proof_pb2.TimeProof
    target_protocol_version: int
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., submitter: _Optional[str] = ..., contract_id: _Optional[str] = ..., target_domain: _Optional[str] = ..., target_time_proof: _Optional[_Union[_time_proof_pb2.TimeProof, _Mapping]] = ..., target_protocol_version: _Optional[int] = ...) -> None: ...

class TransferInCommonData(_message.Message):
    __slots__ = ("salt", "target_domain", "stakeholders", "uuid", "target_mediator", "target_protocol_version")
    SALT_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    TARGET_MEDIATOR_FIELD_NUMBER: _ClassVar[int]
    TARGET_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    target_domain: str
    stakeholders: _containers.RepeatedScalarFieldContainer[str]
    uuid: str
    target_mediator: str
    target_protocol_version: int
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., target_domain: _Optional[str] = ..., stakeholders: _Optional[_Iterable[str]] = ..., uuid: _Optional[str] = ..., target_mediator: _Optional[str] = ..., target_protocol_version: _Optional[int] = ...) -> None: ...

class TransferInView(_message.Message):
    __slots__ = ("salt", "submitter", "contract", "transfer_out_result_event", "creating_transaction_id", "source_protocol_version")
    SALT_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_OUT_RESULT_EVENT_FIELD_NUMBER: _ClassVar[int]
    CREATING_TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    submitter: str
    contract: _common_pb2.SerializableContract
    transfer_out_result_event: _sequencing_pb2.SignedContent
    creating_transaction_id: bytes
    source_protocol_version: int
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., submitter: _Optional[str] = ..., contract: _Optional[_Union[_common_pb2.SerializableContract, _Mapping]] = ..., transfer_out_result_event: _Optional[_Union[_sequencing_pb2.SignedContent, _Mapping]] = ..., creating_transaction_id: _Optional[bytes] = ..., source_protocol_version: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import sequencer_administration_service_pb2 as _sequencer_administration_service_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencerSnapshot(_message.Message):
    __slots__ = ("latest_timestamp", "head_member_counters", "status", "additional")
    class HeadMemberCountersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    LATEST_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    HEAD_MEMBER_COUNTERS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_FIELD_NUMBER: _ClassVar[int]
    latest_timestamp: _timestamp_pb2.Timestamp
    head_member_counters: _containers.ScalarMap[str, int]
    status: _sequencer_administration_service_pb2.SequencerPruningStatus
    additional: ImplementationSpecificInfo
    def __init__(self, latest_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., head_member_counters: _Optional[_Mapping[str, int]] = ..., status: _Optional[_Union[_sequencer_administration_service_pb2.SequencerPruningStatus, _Mapping]] = ..., additional: _Optional[_Union[ImplementationSpecificInfo, _Mapping]] = ...) -> None: ...

class ImplementationSpecificInfo(_message.Message):
    __slots__ = ("implementation_name", "info")
    IMPLEMENTATION_NAME_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    implementation_name: str
    info: bytes
    def __init__(self, implementation_name: _Optional[str] = ..., info: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v30/submission_tracking.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/protocol/v30/submission_tracking.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_sync_event_pb2 as com_dot_digitalasset_dot_canton_dot_participant_dot_protocol_dot_v30_dot_ledger__sync__event__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJcom/digitalasset/canton/participant/protocol/v30/submission_tracking.proto\x12\x30\x63om.digitalasset.canton.participant.protocol.v30\x1aHcom/digitalasset/canton/participant/protocol/v30/ledger_sync_event.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x9d\x01\n\x16SubmissionTrackingData\x12w\n\x0btransaction\x18\x01 \x01(\x0b\x32S.com.digitalasset.canton.participant.protocol.v30.TransactionSubmissionTrackingDataH\x00R\x0btransactionB\n\n\x08tracking\"\xa7\x04\n!TransactionSubmissionTrackingData\x12i\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x8b\x01\n\x0frejection_cause\x18\x02 \x01(\x0b\x32\x62.com.digitalasset.canton.participant.protocol.v30.TransactionSubmissionTrackingData.RejectionCauseR\x0erejectionCause\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x1a\xeb\x01\n\x0eRejectionCause\x12\x32\n\x07timeout\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07timeout\x12\x9b\x01\n\x19rejection_reason_template\x18\x02 \x01(\x0b\x32].com.digitalasset.canton.participant.protocol.v30.CommandRejected.GrpcRejectionReasonTemplateH\x00R\x17rejectionReasonTemplateB\x07\n\x05\x63\x61useBaZ_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v30.submission_tracking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30'
  _globals['_SUBMISSIONTRACKINGDATA']._serialized_start=232
  _globals['_SUBMISSIONTRACKINGDATA']._serialized_end=389
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA']._serialized_start=392
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA']._serialized_end=943
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA_REJECTIONCAUSE']._serialized_start=708
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA_REJECTIONCAUSE']._serialized_end=943
# @@protoc_insertion_point(module_scope)
